@@ -15,18 +15,12 @@ function(coords, plnms, goo = 'Dots2GE.kml'){
 
 
   ## internal function  
-  plmrk.inj = function(i) plmark.fun(plnms[i], Xs[i], Ys[i])
+  plmrk.inj = function(i, plnms, Xs, Ys) plmark.fun(plnms[i], Xs[i], Ys[i])
 
 
   ## kml production
-  assign('plnms', as.character(plnms), envir=.GlobalEnv)
-  assign('Xs', Xs, envir=.GlobalEnv)
-  assign('Ys', Ys, envir=.GlobalEnv)
-  assign('goo', goo, envir=.GlobalEnv)
-
   cat("<?xml version=\"1.0\"?>\n<kml xmlns=\"http://earth.google.com/kml/2.0\">\n<Document>", file = goo, append = FALSE)
   cat("<description>Produced using Dots2GE R script</description>\n<name>R2G2 - Dots2GE</name>\n<open>0</open>", file = goo, append = TRUE)
-  sapply(1:length(plnms), plmrk.inj)
+  sapply(1:length(plnms), plmrk.inj, plnms, Xs, Ys)
   cat("</Document>", "\n", "</kml>", file = goo, append = TRUE)
-  }
-
+  }
\ No newline at end of file
